--------------------------------------------------------------------------------
--
--                COPYRIGHT (C) 2000-2001 - LSI LOGIC.
--    All rights reserved. Reproduction in whole or part is prohibited
--          without the written permission of the copyright owner.
--
--------------------------------------------------------------------------------

---------------------------------------------------------------------------
-- Entity declaration of 'PROC_COMB_SEC'
---------------------------------------------------------------------------

library ieee                 ;

use ieee.std_logic_1164.all  ;
use ieee.std_logic_arith.all ;

use WORK.package_g12.all     ;

ENTITY proc_comb_sec IS
  port(
       GCLEAR ,
       CK     : IN  std_ulogic ;
    
       ELAB_COL0 ,
       ELAB_COL1 ,
       ELAB_COL2 ,
       ELAB_COL3 ,
       ELAB_COL4 ,
       ELAB_COL5 ,
       ELAB_COL6 ,
       ELAB_COL7 ,
    
       PRED0_COL0 ,
       PRED1_COL0 ,
       PRED2_COL0 ,
       PRED3_COL0 ,
       PRED0_COL1 ,
       PRED1_COL1 ,
       PRED2_COL1 ,
       PRED3_COL1 ,
       PRED0_COL2 ,
       PRED1_COL2 ,
       PRED2_COL2 ,
       PRED3_COL2 ,
       PRED0_COL3 ,
       PRED1_COL3 ,
       PRED2_COL3 ,
       PRED3_COL3 ,
       PRED0_COL4 ,
       PRED1_COL4 ,
       PRED2_COL4 ,
       PRED3_COL4 ,
       PRED0_COL5 ,
       PRED1_COL5 ,
       PRED2_COL5 ,
       PRED3_COL5 ,
       PRED0_COL6 ,
       PRED1_COL6 ,
       PRED2_COL6 ,
       PRED3_COL6 ,
       PRED0_COL7 ,
       PRED1_COL7 ,
       PRED2_COL7 ,
       PRED3_COL7 : IN  array_8bit(7 downto 0) ;
       
       P0_ENERGY  ,
       P1_ENERGY  , 
       P2_ENERGY  , 
       P3_ENERGY  : OUT std_ulogic_vector(13 downto 0) ) ;
END proc_comb_sec ;


---------------------------------------------------------------------------
-- Architecture 'beh' of 'PROC_COMB_SEC'
---------------------------------------------------------------------------

architecture beh of proc_comb_sec is

    -- Component declaration --
    component proc_col_sec
    port(
         CK     ,
         GCLEAR : IN  std_ulogic ;
         ELAB   ,
         PRED0  ,
         PRED1  ,
         PRED2  ,
         PRED3  : IN array_8bit(7 downto 0) ;
         COL_P0 ,
         COL_P1 ,
         COL_P2 ,
         COL_P3 : OUT std_ulogic_vector(11 downto 0) ) ;
    end component ;
    
    component proc_fcomp_sec
    port(
         CK         ,
         GCLEAR     : IN  std_ulogic ;
         SUM_COL_P0 ,
         SUM_COL_P1 ,
         SUM_COL_P2 ,
         SUM_COL_P3 : IN array_12bit(7 downto 0) ;
         P0_FSUM    ,
         P1_FSUM    ,
         P2_FSUM    ,
         P3_FSUM    : OUT std_ulogic_vector(13 downto 0) ) ;
    end component ;
    
                                     
    -- Signal declaration --
    signal sum_column_p0 ,
           sum_column_p1 ,
           sum_column_p2 ,
           sum_column_p3 : array_12bit(7 downto 0) ;
           
    signal comp_energy_p0 ,
           comp_energy_p1 ,
           comp_energy_p2 ,
           comp_energy_p3 : std_ulogic_vector(13 downto 0) ;       
           

BEGIN

        -- *** Column computing *** --
        
xc0 : proc_col_sec
      port map(
         CK     => CK               ,
         GCLEAR => GCLEAR           ,
         ELAB   => ELAB_COL0        ,
         PRED0  => PRED0_COL0       ,
         PRED1  => PRED1_COL0       ,
         PRED2  => PRED2_COL0       ,
         PRED3  => PRED3_COL0       ,
         COL_P0 => sum_column_p0(0) ,
         COL_P1 => sum_column_p1(0) ,
         COL_P2 => sum_column_p2(0) ,
         COL_P3 => sum_column_p3(0)  ) ;

xc1 : proc_col_sec
      port map(
         CK     => CK               ,
         GCLEAR => GCLEAR           ,
         ELAB   => ELAB_COL1        ,
         PRED0  => PRED0_COL1       ,
         PRED1  => PRED1_COL1       ,
         PRED2  => PRED2_COL1       ,
         PRED3  => PRED3_COL1       ,
         COL_P0 => sum_column_p0(1) ,
         COL_P1 => sum_column_p1(1) ,
         COL_P2 => sum_column_p2(1) ,
         COL_P3 => sum_column_p3(1)  ) ;
         
xc2 : proc_col_sec
      port map(
         CK     => CK               ,
         GCLEAR => GCLEAR           ,
         ELAB   => ELAB_COL2        ,
         PRED0  => PRED0_COL2       ,
         PRED1  => PRED1_COL2       ,
         PRED2  => PRED2_COL2       ,
         PRED3  => PRED3_COL2       ,
         COL_P0 => sum_column_p0(2) ,
         COL_P1 => sum_column_p1(2) ,
         COL_P2 => sum_column_p2(2) ,
         COL_P3 => sum_column_p3(2)  ) ;

xc3 : proc_col_sec
      port map(
         CK     => CK               ,
         GCLEAR => GCLEAR           ,
         ELAB   => ELAB_COL3        ,
         PRED0  => PRED0_COL3       ,
         PRED1  => PRED1_COL3       ,
         PRED2  => PRED2_COL3       ,
         PRED3  => PRED3_COL3       ,
         COL_P0 => sum_column_p0(3) ,
         COL_P1 => sum_column_p1(3) ,
         COL_P2 => sum_column_p2(3) ,
         COL_P3 => sum_column_p3(3)  ) ;

xc4 : proc_col_sec
      port map(
         CK     => CK               ,
         GCLEAR => GCLEAR           ,
         ELAB   => ELAB_COL4        ,
         PRED0  => PRED0_COL4       ,
         PRED1  => PRED1_COL4       ,
         PRED2  => PRED2_COL4       ,
         PRED3  => PRED3_COL4       ,
         COL_P0 => sum_column_p0(4) ,
         COL_P1 => sum_column_p1(4) ,
         COL_P2 => sum_column_p2(4) ,
         COL_P3 => sum_column_p3(4)  ) ;

xc5 : proc_col_sec
      port map(
         CK     => CK               ,
         GCLEAR => GCLEAR           ,
         ELAB   => ELAB_COL5        ,
         PRED0  => PRED0_COL5       ,
         PRED1  => PRED1_COL5       ,
         PRED2  => PRED2_COL5       ,
         PRED3  => PRED3_COL5       ,
         COL_P0 => sum_column_p0(5) ,
         COL_P1 => sum_column_p1(5) ,
         COL_P2 => sum_column_p2(5) ,
         COL_P3 => sum_column_p3(5)  ) ;
         
xc6 : proc_col_sec
      port map(
         CK     => CK               ,
         GCLEAR => GCLEAR           ,
         ELAB   => ELAB_COL6        ,
         PRED0  => PRED0_COL6       ,
         PRED1  => PRED1_COL6       ,
         PRED2  => PRED2_COL6       ,
         PRED3  => PRED3_COL6       ,
         COL_P0 => sum_column_p0(6) ,
         COL_P1 => sum_column_p1(6) ,
         COL_P2 => sum_column_p2(6) ,
         COL_P3 => sum_column_p3(6)  ) ;         
         

xc7 : proc_col_sec
      port map(
         CK     => CK               ,
         GCLEAR => GCLEAR           ,
         ELAB   => ELAB_COL7        ,
         PRED0  => PRED0_COL7       ,
         PRED1  => PRED1_COL7       ,
         PRED2  => PRED2_COL7       ,
         PRED3  => PRED3_COL7       ,
         COL_P0 => sum_column_p0(7) ,
         COL_P1 => sum_column_p1(7) ,
         COL_P2 => sum_column_p2(7) ,
         COL_P3 => sum_column_p3(7)  ) ;

        -- *** Final computing *** --
xa0 : proc_fcomp_sec
      port map(
         CK         => CK             ,
         GCLEAR     => GCLEAR         ,
         SUM_COL_P0 => sum_column_p0  ,
         SUM_COL_P1 => sum_column_p1  ,
         SUM_COL_P2 => sum_column_p2  ,
         SUM_COL_P3 => sum_column_p3  ,
         P0_FSUM    => comp_energy_p0 ,
         P1_FSUM    => comp_energy_p1 ,
         P2_FSUM    => comp_energy_p2 ,
         P3_FSUM    => comp_energy_p3  ) ;

     -- ass.
     P0_ENERGY <= comp_energy_p0 ;
     P1_ENERGY <= comp_energy_p1 ;
     P2_ENERGY <= comp_energy_p2 ;
     P3_ENERGY <= comp_energy_p3 ;     
     
END beh ;

