/******************************************************************************
**  Module:                cpu_edt_decompressor
**  Tessent Shell version: 2013.4
**  IP version:            5
**  Date:                  Mon Dec 30 11:40:48 2013
******************************************************************************/

module cpu_edt_decompressor (edt_clock, edt_update, edt_channels_in, 
        edt_scan_in);
   input         edt_clock;
   input         edt_update;
   input  [ 3:0] edt_channels_in;
   output [19:0] edt_scan_in;

   reg    [19:0] edt_scan_in;
   reg    [15:0] lfsm_vec;
   reg    [15:0] lfsm_vec_lockup;

   // synopsys sync_set_reset edt_update
   always @(posedge edt_clock)
   begin : lfsm
      if (edt_update == 1'b1) begin
         lfsm_vec <= 16'b0000000000000000;
      end
      else begin
         lfsm_vec[ 0] <= lfsm_vec[ 1];
         lfsm_vec[ 1] <= lfsm_vec[ 2] ^ edt_channels_in[1];
         lfsm_vec[ 2] <= lfsm_vec[ 3];
         lfsm_vec[ 3] <= lfsm_vec[ 4] ^ edt_channels_in[2];
         lfsm_vec[ 4] <= lfsm_vec[ 5];
         lfsm_vec[ 5] <= lfsm_vec[ 6] ^ edt_channels_in[3];
         lfsm_vec[ 6] <= lfsm_vec[ 7];
         lfsm_vec[ 7] <= lfsm_vec[ 8] ^ edt_channels_in[3];
         lfsm_vec[ 8] <= lfsm_vec[ 9] ^ lfsm_vec[ 6];
         lfsm_vec[ 9] <= lfsm_vec[10] ^ edt_channels_in[2];
         lfsm_vec[10] <= lfsm_vec[11] ^ lfsm_vec[ 4];
         lfsm_vec[11] <= lfsm_vec[12] ^ edt_channels_in[1];
         lfsm_vec[12] <= lfsm_vec[13] ^ lfsm_vec[ 3];
         lfsm_vec[13] <= lfsm_vec[14] ^ edt_channels_in[0];
         lfsm_vec[14] <= lfsm_vec[15];
         lfsm_vec[15] <= lfsm_vec[ 0] ^ edt_channels_in[0];
      end
   end

   always @(negedge edt_clock)
   begin : lockup_cells
      lfsm_vec_lockup <= lfsm_vec;
   end

   always @(lfsm_vec_lockup)
   begin : phase_shifter
      edt_scan_in[ 0] = lfsm_vec_lockup[ 6] ^ lfsm_vec_lockup[ 8] ^ lfsm_vec_lockup[ 9];
      edt_scan_in[ 1] = lfsm_vec_lockup[ 1] ^ lfsm_vec_lockup[ 4] ^ lfsm_vec_lockup[13];
      edt_scan_in[ 2] = lfsm_vec_lockup[ 3] ^ lfsm_vec_lockup[10] ^ lfsm_vec_lockup[15];
      edt_scan_in[ 3] = lfsm_vec_lockup[ 0] ^ lfsm_vec_lockup[ 7] ^ lfsm_vec_lockup[14];
      edt_scan_in[ 4] = lfsm_vec_lockup[ 2] ^ lfsm_vec_lockup[ 5] ^ lfsm_vec_lockup[12];
      edt_scan_in[ 5] = lfsm_vec_lockup[ 1] ^ lfsm_vec_lockup[ 9] ^ lfsm_vec_lockup[12];
      edt_scan_in[ 6] = lfsm_vec_lockup[ 6] ^ lfsm_vec_lockup[ 7] ^ lfsm_vec_lockup[14];
      edt_scan_in[ 7] = lfsm_vec_lockup[ 0] ^ lfsm_vec_lockup[ 8] ^ lfsm_vec_lockup[15];
      edt_scan_in[ 8] = lfsm_vec_lockup[10] ^ lfsm_vec_lockup[11] ^ lfsm_vec_lockup[13];
      edt_scan_in[ 9] = lfsm_vec_lockup[ 2] ^ lfsm_vec_lockup[ 3] ^ lfsm_vec_lockup[11];
      edt_scan_in[10] = lfsm_vec_lockup[ 2] ^ lfsm_vec_lockup[ 4] ^ lfsm_vec_lockup[15];
      edt_scan_in[11] = lfsm_vec_lockup[ 8] ^ lfsm_vec_lockup[13] ^ lfsm_vec_lockup[14];
      edt_scan_in[12] = lfsm_vec_lockup[ 5] ^ lfsm_vec_lockup[ 6] ^ lfsm_vec_lockup[12];
      edt_scan_in[13] = lfsm_vec_lockup[ 1] ^ lfsm_vec_lockup[ 5] ^ lfsm_vec_lockup[11];
      edt_scan_in[14] = lfsm_vec_lockup[ 0] ^ lfsm_vec_lockup[ 4] ^ lfsm_vec_lockup[10];
      edt_scan_in[15] = lfsm_vec_lockup[ 2] ^ lfsm_vec_lockup[ 7] ^ lfsm_vec_lockup[ 9];
      edt_scan_in[16] = lfsm_vec_lockup[ 1] ^ lfsm_vec_lockup[ 4] ^ lfsm_vec_lockup[ 5];
      edt_scan_in[17] = lfsm_vec_lockup[ 7] ^ lfsm_vec_lockup[ 8] ^ lfsm_vec_lockup[ 9];
      edt_scan_in[18] = lfsm_vec_lockup[ 0] ^ lfsm_vec_lockup[ 6] ^ lfsm_vec_lockup[13];
      edt_scan_in[19] = lfsm_vec_lockup[11] ^ lfsm_vec_lockup[12] ^ lfsm_vec_lockup[15];
   end

endmodule


/******************************************************************************
**  Module:                cpu_edt_onehot_decoder_3_to_5
**  Tessent Shell version: 2013.4
**  IP version:            5
**  Date:                  Mon Dec 30 11:40:48 2013
******************************************************************************/

module cpu_edt_onehot_decoder_3_to_5 (encoded_masks, decoded_masks);
   input  [2:0] encoded_masks;
   output [4:0] decoded_masks;

   reg    [4:0] decoded_masks;

   always @(encoded_masks)
   begin
      case (encoded_masks)
         3'b000:  decoded_masks = 5'b00000;
         3'b001:  decoded_masks = 5'b00001;
         3'b010:  decoded_masks = 5'b00010;
         3'b011:  decoded_masks = 5'b00100;
         3'b100:  decoded_masks = 5'b01000;
         3'b101:  decoded_masks = 5'b10000;
         default: decoded_masks = 5'b11111;
      endcase
   end
endmodule


/******************************************************************************
**  Module:                cpu_edt_xor_decoder
**  Tessent Shell version: 2013.4
**  IP version:            5
**  Date:                  Mon Dec 30 11:40:48 2013
******************************************************************************/

module cpu_edt_xor_decoder (encoded_masks, decoded_masks_0, decoded_masks_1, 
        decoded_masks_2, decoded_masks_3);
   input  [19:0] encoded_masks;
   output [ 4:0] decoded_masks_0;
   output [ 4:0] decoded_masks_1;
   output [ 4:0] decoded_masks_2;
   output [ 4:0] decoded_masks_3;

   assign decoded_masks_0[0] = encoded_masks[ 0];
   assign decoded_masks_0[1] = encoded_masks[ 1];
   assign decoded_masks_0[2] = encoded_masks[ 2];
   assign decoded_masks_0[3] = encoded_masks[ 3];
   assign decoded_masks_0[4] = encoded_masks[ 4];

   assign decoded_masks_1[0] = encoded_masks[ 5];
   assign decoded_masks_1[1] = encoded_masks[ 6];
   assign decoded_masks_1[2] = encoded_masks[ 7];
   assign decoded_masks_1[3] = encoded_masks[ 8];
   assign decoded_masks_1[4] = encoded_masks[ 9];

   assign decoded_masks_2[0] = encoded_masks[10];
   assign decoded_masks_2[1] = encoded_masks[11];
   assign decoded_masks_2[2] = encoded_masks[12];
   assign decoded_masks_2[3] = encoded_masks[13];
   assign decoded_masks_2[4] = encoded_masks[14];

   assign decoded_masks_3[0] = encoded_masks[15];
   assign decoded_masks_3[1] = encoded_masks[16];
   assign decoded_masks_3[2] = encoded_masks[17];
   assign decoded_masks_3[3] = encoded_masks[18];
   assign decoded_masks_3[4] = encoded_masks[19];

endmodule


/******************************************************************************
**  Module:                cpu_edt_controller
**  Tessent Shell version: 2013.4
**  IP version:            5
**  Date:                  Mon Dec 30 11:40:48 2013
******************************************************************************/

module cpu_edt_controller (edt_clock, edt_update, edt_channels_in, 
        edt_channels_out_from_controller, masks_for_compactor_0, 
        masks_for_compactor_1, masks_for_compactor_2, masks_for_compactor_3);
   input        edt_clock;
   input        edt_update;
   input  [3:0] edt_channels_in;
   output [3:0] edt_channels_out_from_controller;
   output [4:0] masks_for_compactor_0;
   output [4:0] masks_for_compactor_1;
   output [4:0] masks_for_compactor_2;
   output [4:0] masks_for_compactor_3;

   reg    [ 5:0] masks_shift_reg_0;
   reg    [ 4:0] masks_shift_reg_1;
   reg    [ 4:0] masks_shift_reg_2;
   reg    [ 4:0] masks_shift_reg_3;
   reg    [ 5:0] masks_hold_reg_0;
   reg    [ 4:0] masks_hold_reg_1;
   reg    [ 4:0] masks_hold_reg_2;
   reg    [ 4:0] masks_hold_reg_3;
   wire          control_bit;
   wire   [ 2:0] onehot_encoded_masks_0;
   wire   [ 2:0] onehot_encoded_masks_1;
   wire   [ 2:0] onehot_encoded_masks_2;
   wire   [ 2:0] onehot_encoded_masks_3;
   wire   [19:0] xor_encoded_masks;
   wire   [ 4:0] onehot_decoded_masks_0;
   wire   [ 4:0] onehot_decoded_masks_1;
   wire   [ 4:0] onehot_decoded_masks_2;
   wire   [ 4:0] onehot_decoded_masks_3;
   wire   [ 4:0] xor_decoded_masks_0;
   wire   [ 4:0] xor_decoded_masks_1;
   wire   [ 4:0] xor_decoded_masks_2;
   wire   [ 4:0] xor_decoded_masks_3;

   // synopsys sync_set_reset edt_update
   always @(posedge edt_clock)
   begin : update_or_shift_masking_regs
      if (edt_update == 1'b1) begin
         masks_hold_reg_0 <= masks_shift_reg_0;
         masks_hold_reg_1 <= masks_shift_reg_1;
         masks_hold_reg_2 <= masks_shift_reg_2;
         masks_hold_reg_3 <= masks_shift_reg_3;
         masks_shift_reg_0 <= 6'b000000;
         masks_shift_reg_1 <= 5'b00000;
         masks_shift_reg_2 <= 5'b00000;
         masks_shift_reg_3 <= 5'b00000;
      end
      else begin
         masks_shift_reg_0 <= {edt_channels_in[0], masks_shift_reg_0[5:1]};
         masks_shift_reg_1 <= {edt_channels_in[1], masks_shift_reg_1[4:1]};
         masks_shift_reg_2 <= {edt_channels_in[2], masks_shift_reg_2[4:1]};
         masks_shift_reg_3 <= {edt_channels_in[3], masks_shift_reg_3[4:1]};
      end
   end

   assign edt_channels_out_from_controller[0] = masks_shift_reg_0[0];
   assign edt_channels_out_from_controller[1] = masks_shift_reg_1[0];
   assign edt_channels_out_from_controller[2] = masks_shift_reg_2[0];
   assign edt_channels_out_from_controller[3] = masks_shift_reg_3[0];

   assign control_bit = masks_hold_reg_0[5];

   assign xor_encoded_masks = {masks_hold_reg_3[0], masks_hold_reg_3[1], masks_hold_reg_3[2], 
                               masks_hold_reg_3[3], masks_hold_reg_3[4], masks_hold_reg_2[0], 
                               masks_hold_reg_2[1], masks_hold_reg_2[2], masks_hold_reg_2[3], 
                               masks_hold_reg_2[4], masks_hold_reg_1[0], masks_hold_reg_1[1], 
                               masks_hold_reg_1[2], masks_hold_reg_1[3], masks_hold_reg_1[4], 
                               masks_hold_reg_0[0], masks_hold_reg_0[1], masks_hold_reg_0[2], 
                               masks_hold_reg_0[3], masks_hold_reg_0[4]};

   assign onehot_encoded_masks_0 = {masks_hold_reg_0[4], masks_hold_reg_0[3], masks_hold_reg_0[2]};
   assign onehot_encoded_masks_1 = {masks_hold_reg_1[4], masks_hold_reg_1[3], masks_hold_reg_1[2]};
   assign onehot_encoded_masks_2 = {masks_hold_reg_2[4], masks_hold_reg_2[3], masks_hold_reg_2[2]};
   assign onehot_encoded_masks_3 = {masks_hold_reg_3[4], masks_hold_reg_3[3], masks_hold_reg_3[2]};

   cpu_edt_xor_decoder xor_decoder (.encoded_masks(xor_encoded_masks),
                                    .decoded_masks_0(xor_decoded_masks_0),
                                    .decoded_masks_1(xor_decoded_masks_1),
                                    .decoded_masks_2(xor_decoded_masks_2),
                                    .decoded_masks_3(xor_decoded_masks_3));

   cpu_edt_onehot_decoder_3_to_5 decoder1 (.encoded_masks(onehot_encoded_masks_0),
                                           .decoded_masks(onehot_decoded_masks_0));
   cpu_edt_onehot_decoder_3_to_5 decoder2 (.encoded_masks(onehot_encoded_masks_1),
                                           .decoded_masks(onehot_decoded_masks_1));
   cpu_edt_onehot_decoder_3_to_5 decoder3 (.encoded_masks(onehot_encoded_masks_2),
                                           .decoded_masks(onehot_decoded_masks_2));
   cpu_edt_onehot_decoder_3_to_5 decoder4 (.encoded_masks(onehot_encoded_masks_3),
                                           .decoded_masks(onehot_decoded_masks_3));

   assign masks_for_compactor_0 = control_bit ? onehot_decoded_masks_0 : xor_decoded_masks_0;
   assign masks_for_compactor_1 = control_bit ? onehot_decoded_masks_1 : xor_decoded_masks_1;
   assign masks_for_compactor_2 = control_bit ? onehot_decoded_masks_2 : xor_decoded_masks_2;
   assign masks_for_compactor_3 = control_bit ? onehot_decoded_masks_3 : xor_decoded_masks_3;
endmodule


/******************************************************************************
**  Module:                cpu_edt_spatial_compactor_5
**  Tessent Shell version: 2013.4
**  IP version:            5
**  Date:                  Mon Dec 30 11:40:48 2013
******************************************************************************/

module cpu_edt_spatial_compactor_5 (multi_bit_input, single_bit_output);
   input  [4:0] multi_bit_input;
   output       single_bit_output;

   reg          single_bit_output;
   reg    [2:0] level1;
   reg    [1:0] level2;

   always @(multi_bit_input)
   begin : compact5_level1
      level1[0] = multi_bit_input[0] ^ multi_bit_input[1];
      level1[1] = multi_bit_input[2] ^ multi_bit_input[3];
      level1[2] = multi_bit_input[4];
   end

   always @(level1)
   begin : compact5_level2
      level2[0] = level1[0] ^ level1[1];
      level2[1] = level1[2];
   end

   always @(level2)
   begin : compact5_level3
      single_bit_output = level2[0] ^ level2[1];
   end

endmodule


/******************************************************************************
**  Module:                cpu_edt_compactor
**  Tessent Shell version: 2013.4
**  IP version:            5
**  Date:                  Mon Dec 30 11:40:48 2013
******************************************************************************/

module cpu_edt_compactor (edt_scan_out, masks_for_compactor_0, 
        masks_for_compactor_1, masks_for_compactor_2, masks_for_compactor_3, 
        edt_channels_out);
   input  [19:0] edt_scan_out;
   input  [ 4:0] masks_for_compactor_0;
   input  [ 4:0] masks_for_compactor_1;
   input  [ 4:0] masks_for_compactor_2;
   input  [ 4:0] masks_for_compactor_3;
   output [ 3:0] edt_channels_out;

   wire   [4:0] masked_scan_outputs_0;
   wire   [4:0] masked_scan_outputs_1;
   wire   [4:0] masked_scan_outputs_2;
   wire   [4:0] masked_scan_outputs_3;

   assign masked_scan_outputs_0 = edt_scan_out[ 4: 0] & masks_for_compactor_0;
   assign masked_scan_outputs_1 = edt_scan_out[ 9: 5] & masks_for_compactor_1;
   assign masked_scan_outputs_2 = edt_scan_out[14:10] & masks_for_compactor_2;
   assign masked_scan_outputs_3 = edt_scan_out[19:15] & masks_for_compactor_3;

   cpu_edt_spatial_compactor_5 compactor1 (.multi_bit_input(masked_scan_outputs_0),
                                           .single_bit_output(edt_channels_out[0]));
   cpu_edt_spatial_compactor_5 compactor2 (.multi_bit_input(masked_scan_outputs_1),
                                           .single_bit_output(edt_channels_out[1]));
   cpu_edt_spatial_compactor_5 compactor3 (.multi_bit_input(masked_scan_outputs_2),
                                           .single_bit_output(edt_channels_out[2]));
   cpu_edt_spatial_compactor_5 compactor4 (.multi_bit_input(masked_scan_outputs_3),
                                           .single_bit_output(edt_channels_out[3]));
endmodule


/******************************************************************************
**  Module:                cpu_edt_bypass_logic
**  Tessent Shell version: 2013.4
**  IP version:            5
**  Date:                  Mon Dec 30 11:40:48 2013
******************************************************************************/

module cpu_edt_bypass_logic (edt_bypass, edt_channels_in, edt_channels_out, 
        edt_scan_in, edt_scan_out, edt_bypass_in, edt_bypass_out);
   input         edt_bypass;
   input  [ 3:0] edt_channels_in;
   output [ 3:0] edt_channels_out;
   output [19:0] edt_scan_in;
   input  [19:0] edt_scan_out;
   input  [19:0] edt_bypass_in;
   input  [ 3:0] edt_bypass_out;


   assign edt_scan_in[0] = edt_bypass ? edt_channels_in[0] : edt_bypass_in[0];
   assign edt_scan_in[1] = edt_bypass ? edt_scan_out[0] : edt_bypass_in[1];
   assign edt_scan_in[2] = edt_bypass ? edt_scan_out[1] : edt_bypass_in[2];
   assign edt_scan_in[3] = edt_bypass ? edt_scan_out[2] : edt_bypass_in[3];
   assign edt_scan_in[4] = edt_bypass ? edt_scan_out[3] : edt_bypass_in[4];
   assign edt_scan_in[5] = edt_bypass ? edt_channels_in[1] : edt_bypass_in[5];
   assign edt_scan_in[6] = edt_bypass ? edt_scan_out[5] : edt_bypass_in[6];
   assign edt_scan_in[7] = edt_bypass ? edt_scan_out[6] : edt_bypass_in[7];
   assign edt_scan_in[8] = edt_bypass ? edt_scan_out[7] : edt_bypass_in[8];
   assign edt_scan_in[9] = edt_bypass ? edt_scan_out[8] : edt_bypass_in[9];
   assign edt_scan_in[10] = edt_bypass ? edt_channels_in[2] : edt_bypass_in[10];
   assign edt_scan_in[11] = edt_bypass ? edt_scan_out[10] : edt_bypass_in[11];
   assign edt_scan_in[12] = edt_bypass ? edt_scan_out[11] : edt_bypass_in[12];
   assign edt_scan_in[13] = edt_bypass ? edt_scan_out[12] : edt_bypass_in[13];
   assign edt_scan_in[14] = edt_bypass ? edt_scan_out[13] : edt_bypass_in[14];
   assign edt_scan_in[15] = edt_bypass ? edt_channels_in[3] : edt_bypass_in[15];
   assign edt_scan_in[16] = edt_bypass ? edt_scan_out[15] : edt_bypass_in[16];
   assign edt_scan_in[17] = edt_bypass ? edt_scan_out[16] : edt_bypass_in[17];
   assign edt_scan_in[18] = edt_bypass ? edt_scan_out[17] : edt_bypass_in[18];
   assign edt_scan_in[19] = edt_bypass ? edt_scan_out[18] : edt_bypass_in[19];

   assign edt_channels_out[0] = edt_bypass ? edt_scan_out[4] : edt_bypass_out[0];
   assign edt_channels_out[1] = edt_bypass ? edt_scan_out[9] : edt_bypass_out[1];
   assign edt_channels_out[2] = edt_bypass ? edt_scan_out[14] : edt_bypass_out[2];
   assign edt_channels_out[3] = edt_bypass ? edt_scan_out[19] : edt_bypass_out[3];
endmodule


/******************************************************************************
**  Module:                cpu_edt
**  Tessent Shell version: 2013.4
**  IP version:            5
**  Date:                  Mon Dec 30 11:40:48 2013
******************************************************************************/

module cpu_edt (edt_clock, edt_update, edt_bypass, edt_channels_in, 
        edt_channels_out, edt_scan_in, edt_scan_out);
   input         edt_clock;
   input         edt_update;
   input         edt_bypass;
   input  [ 3:0] edt_channels_in;
   output [ 3:0] edt_channels_out;
   output [19:0] edt_scan_in;
   input  [19:0] edt_scan_out;

   wire   [19:0] edt_bypass_in;
   wire   [ 3:0] edt_bypass_out;
   wire   [ 4:0] masks_for_compactor_0;
   wire   [ 4:0] masks_for_compactor_1;
   wire   [ 4:0] masks_for_compactor_2;
   wire   [ 4:0] masks_for_compactor_3;
   wire   [ 3:0] edt_channels_out_from_controller;

   cpu_edt_decompressor cpu_edt_decompressor_i (.edt_clock(edt_clock),
                                                .edt_update(edt_update),
                                                .edt_channels_in(edt_channels_out_from_controller),
                                                .edt_scan_in(edt_bypass_in));

   cpu_edt_compactor cpu_edt_compactor_i (.edt_scan_out(edt_scan_out),
                                          .masks_for_compactor_0(masks_for_compactor_0),
                                          .masks_for_compactor_1(masks_for_compactor_1),
                                          .masks_for_compactor_2(masks_for_compactor_2),
                                          .masks_for_compactor_3(masks_for_compactor_3),
                                          .edt_channels_out(edt_bypass_out));

   cpu_edt_controller cpu_edt_controller_i (.edt_clock(edt_clock),
                                            .edt_update(edt_update),
                                            .edt_channels_in(edt_channels_in),
                                            .edt_channels_out_from_controller(edt_channels_out_from_controller),
                                            .masks_for_compactor_0(masks_for_compactor_0),
                                            .masks_for_compactor_1(masks_for_compactor_1),
                                            .masks_for_compactor_2(masks_for_compactor_2),
                                            .masks_for_compactor_3(masks_for_compactor_3));

   cpu_edt_bypass_logic cpu_edt_bypass_logic_i (.edt_bypass(edt_bypass),
                                                .edt_channels_in(edt_channels_in),
                                                .edt_channels_out(edt_channels_out),
                                                .edt_scan_in(edt_scan_in),
                                                .edt_scan_out(edt_scan_out),
                                                .edt_bypass_in(edt_bypass_in),
                                                .edt_bypass_out(edt_bypass_out));
endmodule


